package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.utils.DateUtil;
import cn.wisenergy.common.utils.R;
import cn.wisenergy.mapper.AntiFakeMapper;
import cn.wisenergy.model.app.AntiFake;
import cn.wisenergy.service.app.AntiFakeService;
import cn.wisenergy.service.util.CodeUtils;
import cn.wisenergy.service.util.FileUtils;
import cn.wisenergy.service.util.QRCodeUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author 86187
 */
@Service
@Slf4j
public class AntiFakeServiceImpl extends ServiceImpl<AntiFakeMapper, AntiFake> implements AntiFakeService {

    private static final String DEST_PATH = "/opt/upload/video";
    @Autowired
    private AntiFakeMapper antiFakeMapper;

    @Override
    public R<Boolean> createCode(Integer number) throws Exception {
        log.info("AntiFakeServiceImpl[]createCode[]input.param.number:" + number);
        if (null == number) {
            return R.error("入参不能为空!");
        }
        //获取最大批次号
        String batch = antiFakeMapper.getByBestBigNumber();
        String batchNumber = "";
        if (StringUtils.isBlank(batch)) {
            batchNumber = "10000001";
        } else {
            Integer sum = Integer.parseInt(batch) + 1;
            batchNumber = String.valueOf(sum);
        }

        int initBatchNo = 10000000;
        String realTime = DateUtil.getTime(new Date(), "yyyy-MM-dd");
        List<AntiFake> list = new ArrayList<>();

        for (int i = 0; i < number; i++) {
            int batchNo = initBatchNo + i + 1;
            AntiFake antiFake = new AntiFake();
            antiFake.setBatchNo(String.valueOf(batchNo));
            antiFake.setBatchNumber(batchNumber);
            antiFake.setProduceTime(realTime);
            antiFake.setScanTime(new Date());

            //生成产品编码
            String productNo = CodeUtils.createProductNo(batchNumber, antiFake.getBatchNo());
            antiFake.setProductNo(productNo);
            antiFake.setStatus(0);

            //生成二维码
            String url = QRCodeUtils.encode(productNo, DEST_PATH);
            antiFake.setUrl(url);
            list.add(antiFake);
        }

        //批量添加二维码
        int count = antiFakeMapper.creates(list);
        if (count != list.size()) {
            return R.error("生成防伪二维码失败!");
        }
        return R.ok(0, true);
    }

    @Override
    public R<String> decode(MultipartFile multipartFile) throws Exception {
        log.info("AntiFakeServiceImpl[]decode[]input.param.multipartFile:" + multipartFile);
        if (null == multipartFile) {
            return R.error("入参为空");
        }

        File file = FileUtils.multipartFileToFile(multipartFile);

        String result = QRCodeUtils.decode(file);
        return R.ok(result);
    }

    @Override
    public R<String> uploadImage() throws Exception {
        log.info("上传二维码防伪图测试");
        //生成二维码
        String url = QRCodeUtils.encode("2021-04022", DEST_PATH);
        return R.ok(url);
    }
}
